# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetVm2Result',
    'AwaitableGetVm2Result',
    'get_vm2',
    'get_vm2_output',
]

@pulumi.output_type
class GetVm2Result:
    """
    A collection of values returned by getVm2.
    """
    def __init__(__self__, clone=None, cpu=None, description=None, id=None, name=None, node_name=None, tags=None, template=None, timeouts=None, vga=None):
        if clone and not isinstance(clone, dict):
            raise TypeError("Expected argument 'clone' to be a dict")
        pulumi.set(__self__, "clone", clone)
        if cpu and not isinstance(cpu, dict):
            raise TypeError("Expected argument 'cpu' to be a dict")
        pulumi.set(__self__, "cpu", cpu)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, int):
            raise TypeError("Expected argument 'id' to be a int")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if node_name and not isinstance(node_name, str):
            raise TypeError("Expected argument 'node_name' to be a str")
        pulumi.set(__self__, "node_name", node_name)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if template and not isinstance(template, bool):
            raise TypeError("Expected argument 'template' to be a bool")
        pulumi.set(__self__, "template", template)
        if timeouts and not isinstance(timeouts, dict):
            raise TypeError("Expected argument 'timeouts' to be a dict")
        pulumi.set(__self__, "timeouts", timeouts)
        if vga and not isinstance(vga, dict):
            raise TypeError("Expected argument 'vga' to be a dict")
        pulumi.set(__self__, "vga", vga)

    @property
    @pulumi.getter
    def clone(self) -> Optional['outputs.GetVm2CloneResult']:
        """
        The cloning configuration.
        """
        return pulumi.get(self, "clone")

    @property
    @pulumi.getter
    def cpu(self) -> 'outputs.GetVm2CpuResult':
        """
        The CPU configuration.
        """
        return pulumi.get(self, "cpu")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        The description of the VM.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> int:
        """
        The unique identifier of the VM in the Proxmox cluster.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name of the VM.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeName")
    def node_name(self) -> str:
        """
        The name of the node where the VM is provisioned.
        """
        return pulumi.get(self, "node_name")

    @property
    @pulumi.getter
    def tags(self) -> Sequence[str]:
        """
        The tags assigned to the VM.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def template(self) -> Optional[bool]:
        """
        Whether the VM is a template.
        """
        return pulumi.get(self, "template")

    @property
    @pulumi.getter
    def timeouts(self) -> Optional['outputs.GetVm2TimeoutsResult']:
        return pulumi.get(self, "timeouts")

    @property
    @pulumi.getter
    def vga(self) -> 'outputs.GetVm2VgaResult':
        """
        The VGA configuration.
        """
        return pulumi.get(self, "vga")


class AwaitableGetVm2Result(GetVm2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVm2Result(
            clone=self.clone,
            cpu=self.cpu,
            description=self.description,
            id=self.id,
            name=self.name,
            node_name=self.node_name,
            tags=self.tags,
            template=self.template,
            timeouts=self.timeouts,
            vga=self.vga)


def get_vm2(clone: Optional[pulumi.InputType['GetVm2CloneArgs']] = None,
            cpu: Optional[pulumi.InputType['GetVm2CpuArgs']] = None,
            description: Optional[str] = None,
            id: Optional[int] = None,
            name: Optional[str] = None,
            node_name: Optional[str] = None,
            tags: Optional[Sequence[str]] = None,
            template: Optional[bool] = None,
            timeouts: Optional[pulumi.InputType['GetVm2TimeoutsArgs']] = None,
            vga: Optional[pulumi.InputType['GetVm2VgaArgs']] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVm2Result:
    """
    !> **DO NOT USE**
    This is an experimental implementation of a Proxmox VM datasource using Plugin Framework.


    :param pulumi.InputType['GetVm2CloneArgs'] clone: The cloning configuration.
    :param pulumi.InputType['GetVm2CpuArgs'] cpu: The CPU configuration.
    :param str description: The description of the VM.
    :param int id: The unique identifier of the VM in the Proxmox cluster.
    :param str name: The name of the VM.
    :param str node_name: The name of the node where the VM is provisioned.
    :param Sequence[str] tags: The tags assigned to the VM.
    :param bool template: Whether the VM is a template.
    :param pulumi.InputType['GetVm2VgaArgs'] vga: The VGA configuration.
    """
    __args__ = dict()
    __args__['clone'] = clone
    __args__['cpu'] = cpu
    __args__['description'] = description
    __args__['id'] = id
    __args__['name'] = name
    __args__['nodeName'] = node_name
    __args__['tags'] = tags
    __args__['template'] = template
    __args__['timeouts'] = timeouts
    __args__['vga'] = vga
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('proxmoxve:index/getVm2:getVm2', __args__, opts=opts, typ=GetVm2Result).value

    return AwaitableGetVm2Result(
        clone=pulumi.get(__ret__, 'clone'),
        cpu=pulumi.get(__ret__, 'cpu'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        node_name=pulumi.get(__ret__, 'node_name'),
        tags=pulumi.get(__ret__, 'tags'),
        template=pulumi.get(__ret__, 'template'),
        timeouts=pulumi.get(__ret__, 'timeouts'),
        vga=pulumi.get(__ret__, 'vga'))


@_utilities.lift_output_func(get_vm2)
def get_vm2_output(clone: Optional[pulumi.Input[Optional[pulumi.InputType['GetVm2CloneArgs']]]] = None,
                   cpu: Optional[pulumi.Input[Optional[pulumi.InputType['GetVm2CpuArgs']]]] = None,
                   description: Optional[pulumi.Input[Optional[str]]] = None,
                   id: Optional[pulumi.Input[int]] = None,
                   name: Optional[pulumi.Input[Optional[str]]] = None,
                   node_name: Optional[pulumi.Input[str]] = None,
                   tags: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                   template: Optional[pulumi.Input[Optional[bool]]] = None,
                   timeouts: Optional[pulumi.Input[Optional[pulumi.InputType['GetVm2TimeoutsArgs']]]] = None,
                   vga: Optional[pulumi.Input[Optional[pulumi.InputType['GetVm2VgaArgs']]]] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVm2Result]:
    """
    !> **DO NOT USE**
    This is an experimental implementation of a Proxmox VM datasource using Plugin Framework.


    :param pulumi.InputType['GetVm2CloneArgs'] clone: The cloning configuration.
    :param pulumi.InputType['GetVm2CpuArgs'] cpu: The CPU configuration.
    :param str description: The description of the VM.
    :param int id: The unique identifier of the VM in the Proxmox cluster.
    :param str name: The name of the VM.
    :param str node_name: The name of the node where the VM is provisioned.
    :param Sequence[str] tags: The tags assigned to the VM.
    :param bool template: Whether the VM is a template.
    :param pulumi.InputType['GetVm2VgaArgs'] vga: The VGA configuration.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetMappingsResult',
    'AwaitableGetMappingsResult',
    'get_mappings',
    'get_mappings_output',
]

@pulumi.output_type
class GetMappingsResult:
    """
    A collection of values returned by getMappings.
    """
    def __init__(__self__, check_node=None, checks=None, id=None, ids=None, type=None):
        if check_node and not isinstance(check_node, str):
            raise TypeError("Expected argument 'check_node' to be a str")
        pulumi.set(__self__, "check_node", check_node)
        if checks and not isinstance(checks, list):
            raise TypeError("Expected argument 'checks' to be a list")
        pulumi.set(__self__, "checks", checks)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="checkNode")
    def check_node(self) -> Optional[str]:
        """
        The name of the node whose configurations should be checked for correctness.
        """
        return pulumi.get(self, "check_node")

    @property
    @pulumi.getter
    def checks(self) -> Sequence['outputs.GetMappingsCheckResult']:
        """
        Might contain relevant diagnostics about incorrect configurations.
        """
        return pulumi.get(self, "checks")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The unique identifier of this hardware mappings data source.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        The identifiers of the hardware mappings.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of the hardware mappings.
        """
        return pulumi.get(self, "type")


class AwaitableGetMappingsResult(GetMappingsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMappingsResult(
            check_node=self.check_node,
            checks=self.checks,
            id=self.id,
            ids=self.ids,
            type=self.type)


def get_mappings(check_node: Optional[str] = None,
                 type: Optional[str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMappingsResult:
    """
    Retrieves a list of hardware mapping resources.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_proxmoxve as proxmoxve

    example_pci = proxmoxve.Hardware.get_mappings(check_node="pve",
        type="pci")
    example_usb = proxmoxve.Hardware.get_mappings(check_node="pve",
        type="usb")
    pulumi.export("dataProxmoxVirtualEnvironmentHardwareMappingsPci", example_pci)
    pulumi.export("dataProxmoxVirtualEnvironmentHardwareMappingsUsb", example_usb)
    ```


    :param str check_node: The name of the node whose configurations should be checked for correctness.
    :param str type: The type of the hardware mappings.
    """
    __args__ = dict()
    __args__['checkNode'] = check_node
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('proxmoxve:Hardware/getMappings:getMappings', __args__, opts=opts, typ=GetMappingsResult).value

    return AwaitableGetMappingsResult(
        check_node=pulumi.get(__ret__, 'check_node'),
        checks=pulumi.get(__ret__, 'checks'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        type=pulumi.get(__ret__, 'type'))


@_utilities.lift_output_func(get_mappings)
def get_mappings_output(check_node: Optional[pulumi.Input[Optional[str]]] = None,
                        type: Optional[pulumi.Input[str]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMappingsResult]:
    """
    Retrieves a list of hardware mapping resources.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_proxmoxve as proxmoxve

    example_pci = proxmoxve.Hardware.get_mappings(check_node="pve",
        type="pci")
    example_usb = proxmoxve.Hardware.get_mappings(check_node="pve",
        type="usb")
    pulumi.export("dataProxmoxVirtualEnvironmentHardwareMappingsPci", example_pci)
    pulumi.export("dataProxmoxVirtualEnvironmentHardwareMappingsUsb", example_usb)
    ```


    :param str check_node: The name of the node whose configurations should be checked for correctness.
    :param str type: The type of the hardware mappings.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from ... import _utilities

__all__ = [
    'PciMap',
    'UsbMap',
    'GetPciMapResult',
    'GetUsbMapResult',
]

@pulumi.output_type
class PciMap(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "iommuGroup":
            suggest = "iommu_group"
        elif key == "subsystemId":
            suggest = "subsystem_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PciMap. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PciMap.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PciMap.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 id: str,
                 node: str,
                 path: str,
                 comment: Optional[str] = None,
                 iommu_group: Optional[int] = None,
                 subsystem_id: Optional[str] = None):
        """
        :param str id: The ID of the map.
        :param str node: The node name of the map.
        :param str path: The path of the map.
        :param str comment: The comment of the mapped PCI device.
        :param int iommu_group: The IOMMU group of the map. Not mandatory for the Proxmox VE API call, but causes a PCI hardware mapping to be incomplete when not set
        :param str subsystem_id: The subsystem ID group of the map. Not mandatory for the Proxmox VE API call, but causes a PCI hardware mapping to be incomplete when not set
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "node", node)
        pulumi.set(__self__, "path", path)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if iommu_group is not None:
            pulumi.set(__self__, "iommu_group", iommu_group)
        if subsystem_id is not None:
            pulumi.set(__self__, "subsystem_id", subsystem_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the map.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def node(self) -> str:
        """
        The node name of the map.
        """
        return pulumi.get(self, "node")

    @property
    @pulumi.getter
    def path(self) -> str:
        """
        The path of the map.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def comment(self) -> Optional[str]:
        """
        The comment of the mapped PCI device.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="iommuGroup")
    def iommu_group(self) -> Optional[int]:
        """
        The IOMMU group of the map. Not mandatory for the Proxmox VE API call, but causes a PCI hardware mapping to be incomplete when not set
        """
        return pulumi.get(self, "iommu_group")

    @property
    @pulumi.getter(name="subsystemId")
    def subsystem_id(self) -> Optional[str]:
        """
        The subsystem ID group of the map. Not mandatory for the Proxmox VE API call, but causes a PCI hardware mapping to be incomplete when not set
        """
        return pulumi.get(self, "subsystem_id")


@pulumi.output_type
class UsbMap(dict):
    def __init__(__self__, *,
                 id: str,
                 node: str,
                 comment: Optional[str] = None,
                 path: Optional[str] = None):
        """
        :param str id: The ID of the map.
        :param str node: The node name of the map.
        :param str comment: The comment of the mapped USB device.
        :param str path: The path of the map. For hardware mappings of type USB the path is optional and indicates that the device is mapped through the device ID instead of ports.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "node", node)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if path is not None:
            pulumi.set(__self__, "path", path)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the map.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def node(self) -> str:
        """
        The node name of the map.
        """
        return pulumi.get(self, "node")

    @property
    @pulumi.getter
    def comment(self) -> Optional[str]:
        """
        The comment of the mapped USB device.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter
    def path(self) -> Optional[str]:
        """
        The path of the map. For hardware mappings of type USB the path is optional and indicates that the device is mapped through the device ID instead of ports.
        """
        return pulumi.get(self, "path")


@pulumi.output_type
class GetPciMapResult(dict):
    def __init__(__self__, *,
                 comment: str,
                 id: str,
                 iommu_group: int,
                 node: str,
                 path: str,
                 subsystem_id: str):
        """
        :param str comment: The comment of the mapped PCI device.
        :param str id: The ID attribute of the map.
        :param int iommu_group: The IOMMU group attribute of the map.
        :param str node: The node name attribute of the map.
        :param str path: The path attribute of the map.
        :param str subsystem_id: The subsystem ID attribute of the map.Not mandatory for the Proxmox VE API call, but causes a PCI hardware mapping to be incomplete when not set.
        """
        pulumi.set(__self__, "comment", comment)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "iommu_group", iommu_group)
        pulumi.set(__self__, "node", node)
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "subsystem_id", subsystem_id)

    @property
    @pulumi.getter
    def comment(self) -> str:
        """
        The comment of the mapped PCI device.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID attribute of the map.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="iommuGroup")
    def iommu_group(self) -> int:
        """
        The IOMMU group attribute of the map.
        """
        return pulumi.get(self, "iommu_group")

    @property
    @pulumi.getter
    def node(self) -> str:
        """
        The node name attribute of the map.
        """
        return pulumi.get(self, "node")

    @property
    @pulumi.getter
    def path(self) -> str:
        """
        The path attribute of the map.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter(name="subsystemId")
    def subsystem_id(self) -> str:
        """
        The subsystem ID attribute of the map.Not mandatory for the Proxmox VE API call, but causes a PCI hardware mapping to be incomplete when not set.
        """
        return pulumi.get(self, "subsystem_id")


@pulumi.output_type
class GetUsbMapResult(dict):
    def __init__(__self__, *,
                 comment: str,
                 id: str,
                 node: str,
                 path: str):
        """
        :param str comment: The comment of the mapped USB device.
        :param str id: The ID attribute of the map.
        :param str node: The node name attribute of the map.
        :param str path: The path attribute of the map.
        """
        pulumi.set(__self__, "comment", comment)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "node", node)
        pulumi.set(__self__, "path", path)

    @property
    @pulumi.getter
    def comment(self) -> str:
        """
        The comment of the mapped USB device.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID attribute of the map.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def node(self) -> str:
        """
        The node name attribute of the map.
        """
        return pulumi.get(self, "node")

    @property
    @pulumi.getter
    def path(self) -> str:
        """
        The path attribute of the map.
        """
        return pulumi.get(self, "path")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'FileSourceFileArgs',
    'FileSourceRawArgs',
]

@pulumi.input_type
class FileSourceFileArgs:
    def __init__(__self__, *,
                 path: pulumi.Input[str],
                 changed: Optional[pulumi.Input[bool]] = None,
                 checksum: Optional[pulumi.Input[str]] = None,
                 file_name: Optional[pulumi.Input[str]] = None,
                 insecure: Optional[pulumi.Input[bool]] = None,
                 min_tls: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] path: A path to a local file or a URL.
        :param pulumi.Input[bool] changed: Whether the source file has changed since the last run
        :param pulumi.Input[str] checksum: The SHA256 checksum of the source file.
        :param pulumi.Input[str] file_name: The file name to use instead of the source file
               name. Useful when the source file does not have a valid file extension,
               for example when the source file is a URL referencing a `.qcow2` image.
        :param pulumi.Input[bool] insecure: Whether to skip the TLS verification step for
               HTTPS sources (defaults to `false`).
        :param pulumi.Input[str] min_tls: The minimum required TLS version for HTTPS
               sources. "Supported values: `1.0|1.1|1.2|1.3` (defaults to `1.3`).
        """
        pulumi.set(__self__, "path", path)
        if changed is not None:
            pulumi.set(__self__, "changed", changed)
        if checksum is not None:
            pulumi.set(__self__, "checksum", checksum)
        if file_name is not None:
            pulumi.set(__self__, "file_name", file_name)
        if insecure is not None:
            pulumi.set(__self__, "insecure", insecure)
        if min_tls is not None:
            pulumi.set(__self__, "min_tls", min_tls)

    @property
    @pulumi.getter
    def path(self) -> pulumi.Input[str]:
        """
        A path to a local file or a URL.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[str]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def changed(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the source file has changed since the last run
        """
        return pulumi.get(self, "changed")

    @changed.setter
    def changed(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "changed", value)

    @property
    @pulumi.getter
    def checksum(self) -> Optional[pulumi.Input[str]]:
        """
        The SHA256 checksum of the source file.
        """
        return pulumi.get(self, "checksum")

    @checksum.setter
    def checksum(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "checksum", value)

    @property
    @pulumi.getter(name="fileName")
    def file_name(self) -> Optional[pulumi.Input[str]]:
        """
        The file name to use instead of the source file
        name. Useful when the source file does not have a valid file extension,
        for example when the source file is a URL referencing a `.qcow2` image.
        """
        return pulumi.get(self, "file_name")

    @file_name.setter
    def file_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "file_name", value)

    @property
    @pulumi.getter
    def insecure(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to skip the TLS verification step for
        HTTPS sources (defaults to `false`).
        """
        return pulumi.get(self, "insecure")

    @insecure.setter
    def insecure(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "insecure", value)

    @property
    @pulumi.getter(name="minTls")
    def min_tls(self) -> Optional[pulumi.Input[str]]:
        """
        The minimum required TLS version for HTTPS
        sources. "Supported values: `1.0|1.1|1.2|1.3` (defaults to `1.3`).
        """
        return pulumi.get(self, "min_tls")

    @min_tls.setter
    def min_tls(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "min_tls", value)


@pulumi.input_type
class FileSourceRawArgs:
    def __init__(__self__, *,
                 data: pulumi.Input[str],
                 file_name: pulumi.Input[str],
                 resize: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] data: The raw data.
        :param pulumi.Input[str] file_name: The file name.
        :param pulumi.Input[int] resize: The number of bytes to resize the file to.
        """
        pulumi.set(__self__, "data", data)
        pulumi.set(__self__, "file_name", file_name)
        if resize is not None:
            pulumi.set(__self__, "resize", resize)

    @property
    @pulumi.getter
    def data(self) -> pulumi.Input[str]:
        """
        The raw data.
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: pulumi.Input[str]):
        pulumi.set(self, "data", value)

    @property
    @pulumi.getter(name="fileName")
    def file_name(self) -> pulumi.Input[str]:
        """
        The file name.
        """
        return pulumi.get(self, "file_name")

    @file_name.setter
    def file_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "file_name", value)

    @property
    @pulumi.getter
    def resize(self) -> Optional[pulumi.Input[int]]:
        """
        The number of bytes to resize the file to.
        """
        return pulumi.get(self, "resize")

    @resize.setter
    def resize(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "resize", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['TokenArgs', 'Token']

@pulumi.input_type
class TokenArgs:
    def __init__(__self__, *,
                 token_name: pulumi.Input[str],
                 user_id: pulumi.Input[str],
                 comment: Optional[pulumi.Input[str]] = None,
                 expiration_date: Optional[pulumi.Input[str]] = None,
                 privileges_separation: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a Token resource.
        :param pulumi.Input[str] token_name: User-specific token identifier.
        :param pulumi.Input[str] user_id: User identifier.
        :param pulumi.Input[str] comment: Comment for the token.
        :param pulumi.Input[str] expiration_date: Expiration date for the token.
        :param pulumi.Input[bool] privileges_separation: Restrict API token privileges with separate ACLs (default), or give full privileges of corresponding user.
        """
        pulumi.set(__self__, "token_name", token_name)
        pulumi.set(__self__, "user_id", user_id)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if expiration_date is not None:
            pulumi.set(__self__, "expiration_date", expiration_date)
        if privileges_separation is not None:
            pulumi.set(__self__, "privileges_separation", privileges_separation)

    @property
    @pulumi.getter(name="tokenName")
    def token_name(self) -> pulumi.Input[str]:
        """
        User-specific token identifier.
        """
        return pulumi.get(self, "token_name")

    @token_name.setter
    def token_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "token_name", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[str]:
        """
        User identifier.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_id", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        Comment for the token.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> Optional[pulumi.Input[str]]:
        """
        Expiration date for the token.
        """
        return pulumi.get(self, "expiration_date")

    @expiration_date.setter
    def expiration_date(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expiration_date", value)

    @property
    @pulumi.getter(name="privilegesSeparation")
    def privileges_separation(self) -> Optional[pulumi.Input[bool]]:
        """
        Restrict API token privileges with separate ACLs (default), or give full privileges of corresponding user.
        """
        return pulumi.get(self, "privileges_separation")

    @privileges_separation.setter
    def privileges_separation(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "privileges_separation", value)


@pulumi.input_type
class _TokenState:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[str]] = None,
                 expiration_date: Optional[pulumi.Input[str]] = None,
                 privileges_separation: Optional[pulumi.Input[bool]] = None,
                 token_name: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Token resources.
        :param pulumi.Input[str] comment: Comment for the token.
        :param pulumi.Input[str] expiration_date: Expiration date for the token.
        :param pulumi.Input[bool] privileges_separation: Restrict API token privileges with separate ACLs (default), or give full privileges of corresponding user.
        :param pulumi.Input[str] token_name: User-specific token identifier.
        :param pulumi.Input[str] user_id: User identifier.
        :param pulumi.Input[str] value: API token value used for authentication. It is populated only when creating a new token, and can't be retrieved at import.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if expiration_date is not None:
            pulumi.set(__self__, "expiration_date", expiration_date)
        if privileges_separation is not None:
            pulumi.set(__self__, "privileges_separation", privileges_separation)
        if token_name is not None:
            pulumi.set(__self__, "token_name", token_name)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        Comment for the token.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> Optional[pulumi.Input[str]]:
        """
        Expiration date for the token.
        """
        return pulumi.get(self, "expiration_date")

    @expiration_date.setter
    def expiration_date(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expiration_date", value)

    @property
    @pulumi.getter(name="privilegesSeparation")
    def privileges_separation(self) -> Optional[pulumi.Input[bool]]:
        """
        Restrict API token privileges with separate ACLs (default), or give full privileges of corresponding user.
        """
        return pulumi.get(self, "privileges_separation")

    @privileges_separation.setter
    def privileges_separation(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "privileges_separation", value)

    @property
    @pulumi.getter(name="tokenName")
    def token_name(self) -> Optional[pulumi.Input[str]]:
        """
        User-specific token identifier.
        """
        return pulumi.get(self, "token_name")

    @token_name.setter
    def token_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token_name", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[str]]:
        """
        User identifier.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_id", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        API token value used for authentication. It is populated only when creating a new token, and can't be retrieved at import.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


class Token(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 expiration_date: Optional[pulumi.Input[str]] = None,
                 privileges_separation: Optional[pulumi.Input[bool]] = None,
                 token_name: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        User API tokens.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_proxmoxve as proxmoxve

        # if creating a user token, the user must be created first
        user = proxmoxve.permission.User("user",
            comment="Managed by Terraform",
            email="user@pve",
            enabled=True,
            expiration_date="2034-01-01T22:00:00Z",
            user_id="user@pve")
        user_token = proxmoxve.user.Token("userToken",
            comment="Managed by Terraform",
            expiration_date="2033-01-01T22:00:00Z",
            token_name="tk1",
            user_id=user.user_id)
        ```

        ## Import

        #!/usr/bin/env sh

        #Tokens can be imported using they identifiers in format `user_id!token_name` format, e.g.:

        ```sh
        $ pulumi import proxmoxve:User/token:Token token1 user@pve!token1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: Comment for the token.
        :param pulumi.Input[str] expiration_date: Expiration date for the token.
        :param pulumi.Input[bool] privileges_separation: Restrict API token privileges with separate ACLs (default), or give full privileges of corresponding user.
        :param pulumi.Input[str] token_name: User-specific token identifier.
        :param pulumi.Input[str] user_id: User identifier.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        User API tokens.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_proxmoxve as proxmoxve

        # if creating a user token, the user must be created first
        user = proxmoxve.permission.User("user",
            comment="Managed by Terraform",
            email="user@pve",
            enabled=True,
            expiration_date="2034-01-01T22:00:00Z",
            user_id="user@pve")
        user_token = proxmoxve.user.Token("userToken",
            comment="Managed by Terraform",
            expiration_date="2033-01-01T22:00:00Z",
            token_name="tk1",
            user_id=user.user_id)
        ```

        ## Import

        #!/usr/bin/env sh

        #Tokens can be imported using they identifiers in format `user_id!token_name` format, e.g.:

        ```sh
        $ pulumi import proxmoxve:User/token:Token token1 user@pve!token1
        ```

        :param str resource_name: The name of the resource.
        :param TokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 expiration_date: Optional[pulumi.Input[str]] = None,
                 privileges_separation: Optional[pulumi.Input[bool]] = None,
                 token_name: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TokenArgs.__new__(TokenArgs)

            __props__.__dict__["comment"] = comment
            __props__.__dict__["expiration_date"] = expiration_date
            __props__.__dict__["privileges_separation"] = privileges_separation
            if token_name is None and not opts.urn:
                raise TypeError("Missing required property 'token_name'")
            __props__.__dict__["token_name"] = token_name
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["value"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["value"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Token, __self__).__init__(
            'proxmoxve:User/token:Token',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comment: Optional[pulumi.Input[str]] = None,
            expiration_date: Optional[pulumi.Input[str]] = None,
            privileges_separation: Optional[pulumi.Input[bool]] = None,
            token_name: Optional[pulumi.Input[str]] = None,
            user_id: Optional[pulumi.Input[str]] = None,
            value: Optional[pulumi.Input[str]] = None) -> 'Token':
        """
        Get an existing Token resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: Comment for the token.
        :param pulumi.Input[str] expiration_date: Expiration date for the token.
        :param pulumi.Input[bool] privileges_separation: Restrict API token privileges with separate ACLs (default), or give full privileges of corresponding user.
        :param pulumi.Input[str] token_name: User-specific token identifier.
        :param pulumi.Input[str] user_id: User identifier.
        :param pulumi.Input[str] value: API token value used for authentication. It is populated only when creating a new token, and can't be retrieved at import.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TokenState.__new__(_TokenState)

        __props__.__dict__["comment"] = comment
        __props__.__dict__["expiration_date"] = expiration_date
        __props__.__dict__["privileges_separation"] = privileges_separation
        __props__.__dict__["token_name"] = token_name
        __props__.__dict__["user_id"] = user_id
        __props__.__dict__["value"] = value
        return Token(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        Comment for the token.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> pulumi.Output[Optional[str]]:
        """
        Expiration date for the token.
        """
        return pulumi.get(self, "expiration_date")

    @property
    @pulumi.getter(name="privilegesSeparation")
    def privileges_separation(self) -> pulumi.Output[bool]:
        """
        Restrict API token privileges with separate ACLs (default), or give full privileges of corresponding user.
        """
        return pulumi.get(self, "privileges_separation")

    @property
    @pulumi.getter(name="tokenName")
    def token_name(self) -> pulumi.Output[str]:
        """
        User-specific token identifier.
        """
        return pulumi.get(self, "token_name")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[str]:
        """
        User identifier.
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter
    def value(self) -> pulumi.Output[str]:
        """
        API token value used for authentication. It is populated only when creating a new token, and can't be retrieved at import.
        """
        return pulumi.get(self, "value")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .acl import *
from .certifi import *
from .dns import *
from .get_node import *
from .get_vm2 import *
from .hosts import *
from .provider import *
from .time import *
from .vm2 import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_proxmoxve.cluster as __cluster
    cluster = __cluster
    import pulumi_proxmoxve.config as __config
    config = __config
    import pulumi_proxmoxve.ct as __ct
    ct = __ct
    import pulumi_proxmoxve.download as __download
    download = __download
    import pulumi_proxmoxve.ha as __ha
    ha = __ha
    import pulumi_proxmoxve.hardware as __hardware
    hardware = __hardware
    import pulumi_proxmoxve.network as __network
    network = __network
    import pulumi_proxmoxve.permission as __permission
    permission = __permission
    import pulumi_proxmoxve.storage as __storage
    storage = __storage
    import pulumi_proxmoxve.user as __user
    user = __user
    import pulumi_proxmoxve.vm as __vm
    vm = __vm
else:
    cluster = _utilities.lazy_import('pulumi_proxmoxve.cluster')
    config = _utilities.lazy_import('pulumi_proxmoxve.config')
    ct = _utilities.lazy_import('pulumi_proxmoxve.ct')
    download = _utilities.lazy_import('pulumi_proxmoxve.download')
    ha = _utilities.lazy_import('pulumi_proxmoxve.ha')
    hardware = _utilities.lazy_import('pulumi_proxmoxve.hardware')
    network = _utilities.lazy_import('pulumi_proxmoxve.network')
    permission = _utilities.lazy_import('pulumi_proxmoxve.permission')
    storage = _utilities.lazy_import('pulumi_proxmoxve.storage')
    user = _utilities.lazy_import('pulumi_proxmoxve.user')
    vm = _utilities.lazy_import('pulumi_proxmoxve.vm')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "proxmoxve",
  "mod": "CT/container",
  "fqn": "pulumi_proxmoxve.ct",
  "classes": {
   "proxmoxve:CT/container:Container": "Container"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Cluster/options",
  "fqn": "pulumi_proxmoxve.cluster",
  "classes": {
   "proxmoxve:Cluster/options:Options": "Options"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Download/file",
  "fqn": "pulumi_proxmoxve.download",
  "classes": {
   "proxmoxve:Download/file:File": "File"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "HA/hAGroup",
  "fqn": "pulumi_proxmoxve.ha",
  "classes": {
   "proxmoxve:HA/hAGroup:HAGroup": "HAGroup"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "HA/hAResource",
  "fqn": "pulumi_proxmoxve.ha",
  "classes": {
   "proxmoxve:HA/hAResource:HAResource": "HAResource"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Hardware/mapping/pci",
  "fqn": "pulumi_proxmoxve.hardware.mapping",
  "classes": {
   "proxmoxve:Hardware/mapping/pci:Pci": "Pci"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Hardware/mapping/usb",
  "fqn": "pulumi_proxmoxve.hardware.mapping",
  "classes": {
   "proxmoxve:Hardware/mapping/usb:Usb": "Usb"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Network/firewall",
  "fqn": "pulumi_proxmoxve.network",
  "classes": {
   "proxmoxve:Network/firewall:Firewall": "Firewall"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Network/firewallAlias",
  "fqn": "pulumi_proxmoxve.network",
  "classes": {
   "proxmoxve:Network/firewallAlias:FirewallAlias": "FirewallAlias"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Network/firewallIPSet",
  "fqn": "pulumi_proxmoxve.network",
  "classes": {
   "proxmoxve:Network/firewallIPSet:FirewallIPSet": "FirewallIPSet"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Network/firewallOptions",
  "fqn": "pulumi_proxmoxve.network",
  "classes": {
   "proxmoxve:Network/firewallOptions:FirewallOptions": "FirewallOptions"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Network/firewallRules",
  "fqn": "pulumi_proxmoxve.network",
  "classes": {
   "proxmoxve:Network/firewallRules:FirewallRules": "FirewallRules"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Network/firewallSecurityGroup",
  "fqn": "pulumi_proxmoxve.network",
  "classes": {
   "proxmoxve:Network/firewallSecurityGroup:FirewallSecurityGroup": "FirewallSecurityGroup"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Network/networkBridge",
  "fqn": "pulumi_proxmoxve.network",
  "classes": {
   "proxmoxve:Network/networkBridge:NetworkBridge": "NetworkBridge"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Network/networkVlan",
  "fqn": "pulumi_proxmoxve.network",
  "classes": {
   "proxmoxve:Network/networkVlan:NetworkVlan": "NetworkVlan"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Permission/group",
  "fqn": "pulumi_proxmoxve.permission",
  "classes": {
   "proxmoxve:Permission/group:Group": "Group"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Permission/pool",
  "fqn": "pulumi_proxmoxve.permission",
  "classes": {
   "proxmoxve:Permission/pool:Pool": "Pool"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Permission/role",
  "fqn": "pulumi_proxmoxve.permission",
  "classes": {
   "proxmoxve:Permission/role:Role": "Role"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Permission/user",
  "fqn": "pulumi_proxmoxve.permission",
  "classes": {
   "proxmoxve:Permission/user:User": "User"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "Storage/file",
  "fqn": "pulumi_proxmoxve.storage",
  "classes": {
   "proxmoxve:Storage/file:File": "File"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "User/token",
  "fqn": "pulumi_proxmoxve.user",
  "classes": {
   "proxmoxve:User/token:Token": "Token"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "VM/virtualMachine",
  "fqn": "pulumi_proxmoxve.vm",
  "classes": {
   "proxmoxve:VM/virtualMachine:VirtualMachine": "VirtualMachine"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "VM/virtualMachine2",
  "fqn": "pulumi_proxmoxve.vm",
  "classes": {
   "proxmoxve:VM/virtualMachine2:VirtualMachine2": "VirtualMachine2"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "index/acl",
  "fqn": "pulumi_proxmoxve",
  "classes": {
   "proxmoxve:index/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "index/certifi",
  "fqn": "pulumi_proxmoxve",
  "classes": {
   "proxmoxve:index/certifi:Certifi": "Certifi"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "index/dNS",
  "fqn": "pulumi_proxmoxve",
  "classes": {
   "proxmoxve:index/dNS:DNS": "DNS"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "index/hosts",
  "fqn": "pulumi_proxmoxve",
  "classes": {
   "proxmoxve:index/hosts:Hosts": "Hosts"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "index/time",
  "fqn": "pulumi_proxmoxve",
  "classes": {
   "proxmoxve:index/time:Time": "Time"
  }
 },
 {
  "pkg": "proxmoxve",
  "mod": "index/vm2",
  "fqn": "pulumi_proxmoxve",
  "classes": {
   "proxmoxve:index/vm2:Vm2": "Vm2"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "proxmoxve",
  "token": "pulumi:providers:proxmoxve",
  "fqn": "pulumi_proxmoxve",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from ... import _utilities

__all__ = [
    'PciMapArgs',
    'UsbMapArgs',
]

@pulumi.input_type
class PciMapArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[str],
                 node: pulumi.Input[str],
                 path: pulumi.Input[str],
                 comment: Optional[pulumi.Input[str]] = None,
                 iommu_group: Optional[pulumi.Input[int]] = None,
                 subsystem_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] id: The ID of the map.
        :param pulumi.Input[str] node: The node name of the map.
        :param pulumi.Input[str] path: The path of the map.
        :param pulumi.Input[str] comment: The comment of the mapped PCI device.
        :param pulumi.Input[int] iommu_group: The IOMMU group of the map. Not mandatory for the Proxmox VE API call, but causes a PCI hardware mapping to be incomplete when not set
        :param pulumi.Input[str] subsystem_id: The subsystem ID group of the map. Not mandatory for the Proxmox VE API call, but causes a PCI hardware mapping to be incomplete when not set
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "node", node)
        pulumi.set(__self__, "path", path)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if iommu_group is not None:
            pulumi.set(__self__, "iommu_group", iommu_group)
        if subsystem_id is not None:
            pulumi.set(__self__, "subsystem_id", subsystem_id)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        """
        The ID of the map.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def node(self) -> pulumi.Input[str]:
        """
        The node name of the map.
        """
        return pulumi.get(self, "node")

    @node.setter
    def node(self, value: pulumi.Input[str]):
        pulumi.set(self, "node", value)

    @property
    @pulumi.getter
    def path(self) -> pulumi.Input[str]:
        """
        The path of the map.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[str]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        The comment of the mapped PCI device.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="iommuGroup")
    def iommu_group(self) -> Optional[pulumi.Input[int]]:
        """
        The IOMMU group of the map. Not mandatory for the Proxmox VE API call, but causes a PCI hardware mapping to be incomplete when not set
        """
        return pulumi.get(self, "iommu_group")

    @iommu_group.setter
    def iommu_group(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "iommu_group", value)

    @property
    @pulumi.getter(name="subsystemId")
    def subsystem_id(self) -> Optional[pulumi.Input[str]]:
        """
        The subsystem ID group of the map. Not mandatory for the Proxmox VE API call, but causes a PCI hardware mapping to be incomplete when not set
        """
        return pulumi.get(self, "subsystem_id")

    @subsystem_id.setter
    def subsystem_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "subsystem_id", value)


@pulumi.input_type
class UsbMapArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[str],
                 node: pulumi.Input[str],
                 comment: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] id: The ID of the map.
        :param pulumi.Input[str] node: The node name of the map.
        :param pulumi.Input[str] comment: The comment of the mapped USB device.
        :param pulumi.Input[str] path: The path of the map. For hardware mappings of type USB the path is optional and indicates that the device is mapped through the device ID instead of ports.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "node", node)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if path is not None:
            pulumi.set(__self__, "path", path)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        """
        The ID of the map.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def node(self) -> pulumi.Input[str]:
        """
        The node name of the map.
        """
        return pulumi.get(self, "node")

    @node.setter
    def node(self, value: pulumi.Input[str]):
        pulumi.set(self, "node", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        The comment of the mapped USB device.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        The path of the map. For hardware mappings of type USB the path is optional and indicates that the device is mapped through the device ID instead of ports.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)


